define(['external-esModule'], (function (externalEsModule) { 'use strict';



	return externalEsModule.default;

}));
